# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/proto/sensor_image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/proto/sensor_image.proto',
  package='apollo.drivers',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(modules/drivers/proto/sensor_image.proto\x12\x0e\x61pollo.drivers\x1a!modules/common/proto/header.proto\"\xa7\x01\n\x05Image\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x10\n\x08\x66rame_id\x18\x02 \x01(\t\x12\x18\n\x10measurement_time\x18\x03 \x01(\x01\x12\x0e\n\x06height\x18\x04 \x01(\r\x12\r\n\x05width\x18\x05 \x01(\r\x12\x10\n\x08\x65ncoding\x18\x06 \x01(\t\x12\x0c\n\x04step\x18\x07 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x08 \x01(\x0c\"\x96\x01\n\x0f\x43ompressedImage\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x10\n\x08\x66rame_id\x18\x02 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x12\x18\n\x10measurement_time\x18\x05 \x01(\x01\x12\x12\n\nframe_type\x18\x06 \x01(\r*\xfb\x05\n\x0bPixelFormat\x12\t\n\x04RGB8\x10\xe9\x07\x12\n\n\x05RGBA8\x10\xea\x07\x12\n\n\x05RGB16\x10\xeb\x07\x12\x0b\n\x06RGBA16\x10\xec\x07\x12\t\n\x04\x42GR8\x10\xed\x07\x12\n\n\x05\x42GRA8\x10\xee\x07\x12\n\n\x05\x42GR16\x10\xef\x07\x12\x0b\n\x06\x42GRA16\x10\xf0\x07\x12\n\n\x05MONO8\x10\xf1\x07\x12\x0b\n\x06MONO16\x10\xf2\x07\x12\x0e\n\tTYPE_8UC1\x10\xd1\x0f\x12\x0e\n\tTYPE_8UC2\x10\xd2\x0f\x12\x0e\n\tTYPE_8UC3\x10\xd3\x0f\x12\x0e\n\tTYPE_8UC4\x10\xd4\x0f\x12\x0e\n\tTYPE_8SC1\x10\xd5\x0f\x12\x0e\n\tTYPE_8SC2\x10\xd6\x0f\x12\x0e\n\tTYPE_8SC3\x10\xd7\x0f\x12\x0e\n\tTYPE_8SC4\x10\xd8\x0f\x12\x0f\n\nTYPE_16UC1\x10\xd9\x0f\x12\x0f\n\nTYPE_16UC2\x10\xda\x0f\x12\x0f\n\nTYPE_16UC3\x10\xdb\x0f\x12\x0f\n\nTYPE_16UC4\x10\xdc\x0f\x12\x0f\n\nTYPE_16SC1\x10\xdd\x0f\x12\x0f\n\nTYPE_16SC2\x10\xde\x0f\x12\x0f\n\nTYPE_16SC3\x10\xdf\x0f\x12\x0f\n\nTYPE_16SC4\x10\xe0\x0f\x12\x0f\n\nTYPE_32SC1\x10\xe1\x0f\x12\x0f\n\nTYPE_32SC2\x10\xe2\x0f\x12\x0f\n\nTYPE_32SC3\x10\xe3\x0f\x12\x0f\n\nTYPE_32SC4\x10\xe4\x0f\x12\x0f\n\nTYPE_32FC1\x10\xe5\x0f\x12\x0f\n\nTYPE_32FC2\x10\xe6\x0f\x12\x0f\n\nTYPE_32FC3\x10\xe7\x0f\x12\x0f\n\nTYPE_32FC4\x10\xe8\x0f\x12\x0f\n\nTYPE_64FC1\x10\xe9\x0f\x12\x0f\n\nTYPE_64FC2\x10\xea\x0f\x12\x0f\n\nTYPE_64FC3\x10\xeb\x0f\x12\x0f\n\nTYPE_64FC4\x10\xec\x0f\x12\x10\n\x0b\x42\x41YER_RGGB8\x10\xb9\x17\x12\x10\n\x0b\x42\x41YER_BGGR8\x10\xba\x17\x12\x10\n\x0b\x42\x41YER_GBRG8\x10\xbb\x17\x12\x10\n\x0b\x42\x41YER_GRBG8\x10\xbc\x17\x12\x11\n\x0c\x42\x41YER_RGGB16\x10\xbd\x17\x12\x11\n\x0c\x42\x41YER_BGGR16\x10\xbe\x17\x12\x11\n\x0c\x42\x41YER_GBRG16\x10\xbf\x17\x12\x11\n\x0c\x42\x41YER_GRBG16\x10\xc0\x17\x12\x0b\n\x06YUV422\x10\xa1\x1f'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])

_PIXELFORMAT = _descriptor.EnumDescriptor(
  name='PixelFormat',
  full_name='apollo.drivers.PixelFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RGB8', index=0, number=1001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RGBA8', index=1, number=1002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RGB16', index=2, number=1003,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RGBA16', index=3, number=1004,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BGR8', index=4, number=1005,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BGRA8', index=5, number=1006,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BGR16', index=6, number=1007,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BGRA16', index=7, number=1008,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONO8', index=8, number=1009,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONO16', index=9, number=1010,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_8UC1', index=10, number=2001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_8UC2', index=11, number=2002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_8UC3', index=12, number=2003,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_8UC4', index=13, number=2004,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_8SC1', index=14, number=2005,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_8SC2', index=15, number=2006,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_8SC3', index=16, number=2007,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_8SC4', index=17, number=2008,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_16UC1', index=18, number=2009,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_16UC2', index=19, number=2010,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_16UC3', index=20, number=2011,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_16UC4', index=21, number=2012,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_16SC1', index=22, number=2013,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_16SC2', index=23, number=2014,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_16SC3', index=24, number=2015,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_16SC4', index=25, number=2016,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_32SC1', index=26, number=2017,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_32SC2', index=27, number=2018,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_32SC3', index=28, number=2019,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_32SC4', index=29, number=2020,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_32FC1', index=30, number=2021,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_32FC2', index=31, number=2022,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_32FC3', index=32, number=2023,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_32FC4', index=33, number=2024,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_64FC1', index=34, number=2025,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_64FC2', index=35, number=2026,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_64FC3', index=36, number=2027,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPE_64FC4', index=37, number=2028,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAYER_RGGB8', index=38, number=3001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAYER_BGGR8', index=39, number=3002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAYER_GBRG8', index=40, number=3003,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAYER_GRBG8', index=41, number=3004,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAYER_RGGB16', index=42, number=3005,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAYER_BGGR16', index=43, number=3006,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAYER_GBRG16', index=44, number=3007,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAYER_GRBG16', index=45, number=3008,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YUV422', index=46, number=4001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=419,
  serialized_end=1182,
)
_sym_db.RegisterEnumDescriptor(_PIXELFORMAT)

PixelFormat = enum_type_wrapper.EnumTypeWrapper(_PIXELFORMAT)
RGB8 = 1001
RGBA8 = 1002
RGB16 = 1003
RGBA16 = 1004
BGR8 = 1005
BGRA8 = 1006
BGR16 = 1007
BGRA16 = 1008
MONO8 = 1009
MONO16 = 1010
TYPE_8UC1 = 2001
TYPE_8UC2 = 2002
TYPE_8UC3 = 2003
TYPE_8UC4 = 2004
TYPE_8SC1 = 2005
TYPE_8SC2 = 2006
TYPE_8SC3 = 2007
TYPE_8SC4 = 2008
TYPE_16UC1 = 2009
TYPE_16UC2 = 2010
TYPE_16UC3 = 2011
TYPE_16UC4 = 2012
TYPE_16SC1 = 2013
TYPE_16SC2 = 2014
TYPE_16SC3 = 2015
TYPE_16SC4 = 2016
TYPE_32SC1 = 2017
TYPE_32SC2 = 2018
TYPE_32SC3 = 2019
TYPE_32SC4 = 2020
TYPE_32FC1 = 2021
TYPE_32FC2 = 2022
TYPE_32FC3 = 2023
TYPE_32FC4 = 2024
TYPE_64FC1 = 2025
TYPE_64FC2 = 2026
TYPE_64FC3 = 2027
TYPE_64FC4 = 2028
BAYER_RGGB8 = 3001
BAYER_BGGR8 = 3002
BAYER_GBRG8 = 3003
BAYER_GRBG8 = 3004
BAYER_RGGB16 = 3005
BAYER_BGGR16 = 3006
BAYER_GBRG16 = 3007
BAYER_GRBG16 = 3008
YUV422 = 4001



_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='apollo.drivers.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.Image.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.Image.frame_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_time', full_name='apollo.drivers.Image.measurement_time', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.drivers.Image.height', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.drivers.Image.width', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoding', full_name='apollo.drivers.Image.encoding', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='apollo.drivers.Image.step', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='apollo.drivers.Image.data', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=263,
)


_COMPRESSEDIMAGE = _descriptor.Descriptor(
  name='CompressedImage',
  full_name='apollo.drivers.CompressedImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.CompressedImage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.CompressedImage.frame_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='apollo.drivers.CompressedImage.format', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='apollo.drivers.CompressedImage.data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_time', full_name='apollo.drivers.CompressedImage.measurement_time', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_type', full_name='apollo.drivers.CompressedImage.frame_type', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=416,
)

_IMAGE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_COMPRESSEDIMAGE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
DESCRIPTOR.message_types_by_name['CompressedImage'] = _COMPRESSEDIMAGE
DESCRIPTOR.enum_types_by_name['PixelFormat'] = _PIXELFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {
  'DESCRIPTOR' : _IMAGE,
  '__module__' : 'modules.drivers.proto.sensor_image_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.Image)
  })
_sym_db.RegisterMessage(Image)

CompressedImage = _reflection.GeneratedProtocolMessageType('CompressedImage', (_message.Message,), {
  'DESCRIPTOR' : _COMPRESSEDIMAGE,
  '__module__' : 'modules.drivers.proto.sensor_image_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.CompressedImage)
  })
_sym_db.RegisterMessage(CompressedImage)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/scheduler_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cyber.proto import classic_conf_pb2 as cyber_dot_proto_dot_classic__conf__pb2
from cyber.proto import choreography_conf_pb2 as cyber_dot_proto_dot_choreography__conf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/scheduler_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n cyber/proto/scheduler_conf.proto\x12\x12\x61pollo.cyber.proto\x1a\x1e\x63yber/proto/classic_conf.proto\x1a#cyber/proto/choreography_conf.proto\"L\n\x0bInnerThread\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x63puset\x18\x02 \x01(\t\x12\x0e\n\x06policy\x18\x03 \x01(\t\x12\x0f\n\x04prio\x18\x04 \x01(\r:\x01\x31\"\x96\x02\n\rSchedulerConf\x12\x0e\n\x06policy\x18\x01 \x01(\t\x12\x13\n\x0broutine_num\x18\x02 \x01(\r\x12\x18\n\x10\x64\x65\x66\x61ult_proc_num\x18\x03 \x01(\r\x12\x1c\n\x14process_level_cpuset\x18\x04 \x01(\t\x12\x30\n\x07threads\x18\x05 \x03(\x0b\x32\x1f.apollo.cyber.proto.InnerThread\x12\x35\n\x0c\x63lassic_conf\x18\x06 \x01(\x0b\x32\x1f.apollo.cyber.proto.ClassicConf\x12?\n\x11\x63horeography_conf\x18\x07 \x01(\x0b\x32$.apollo.cyber.proto.ChoreographyConf'
  ,
  dependencies=[cyber_dot_proto_dot_classic__conf__pb2.DESCRIPTOR,cyber_dot_proto_dot_choreography__conf__pb2.DESCRIPTOR,])




_INNERTHREAD = _descriptor.Descriptor(
  name='InnerThread',
  full_name='apollo.cyber.proto.InnerThread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.cyber.proto.InnerThread.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpuset', full_name='apollo.cyber.proto.InnerThread.cpuset', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy', full_name='apollo.cyber.proto.InnerThread.policy', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prio', full_name='apollo.cyber.proto.InnerThread.prio', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=201,
)


_SCHEDULERCONF = _descriptor.Descriptor(
  name='SchedulerConf',
  full_name='apollo.cyber.proto.SchedulerConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='policy', full_name='apollo.cyber.proto.SchedulerConf.policy', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routine_num', full_name='apollo.cyber.proto.SchedulerConf.routine_num', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_proc_num', full_name='apollo.cyber.proto.SchedulerConf.default_proc_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_level_cpuset', full_name='apollo.cyber.proto.SchedulerConf.process_level_cpuset', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threads', full_name='apollo.cyber.proto.SchedulerConf.threads', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classic_conf', full_name='apollo.cyber.proto.SchedulerConf.classic_conf', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choreography_conf', full_name='apollo.cyber.proto.SchedulerConf.choreography_conf', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=482,
)

_SCHEDULERCONF.fields_by_name['threads'].message_type = _INNERTHREAD
_SCHEDULERCONF.fields_by_name['classic_conf'].message_type = cyber_dot_proto_dot_classic__conf__pb2._CLASSICCONF
_SCHEDULERCONF.fields_by_name['choreography_conf'].message_type = cyber_dot_proto_dot_choreography__conf__pb2._CHOREOGRAPHYCONF
DESCRIPTOR.message_types_by_name['InnerThread'] = _INNERTHREAD
DESCRIPTOR.message_types_by_name['SchedulerConf'] = _SCHEDULERCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InnerThread = _reflection.GeneratedProtocolMessageType('InnerThread', (_message.Message,), {
  'DESCRIPTOR' : _INNERTHREAD,
  '__module__' : 'cyber.proto.scheduler_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.InnerThread)
  })
_sym_db.RegisterMessage(InnerThread)

SchedulerConf = _reflection.GeneratedProtocolMessageType('SchedulerConf', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULERCONF,
  '__module__' : 'cyber.proto.scheduler_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.SchedulerConf)
  })
_sym_db.RegisterMessage(SchedulerConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/dreamview/proto/preprocess_table.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/dreamview/proto/preprocess_table.proto',
  package='apollo.dreamview',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.modules/dreamview/proto/preprocess_table.proto\x12\x10\x61pollo.dreamview\".\n\x0bTranslation\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"V\n\x0bLidarConfig\x12\x13\n\x0bsensor_name\x18\x01 \x01(\t\x12\x32\n\x0btranslation\x18\x02 \x01(\x0b\x32\x1d.apollo.dreamview.Translation\"X\n\x0c\x43\x61meraConfig\x12\x32\n\x0btranslation\x18\x01 \x01(\x0b\x32\x1d.apollo.dreamview.Translation\x12\t\n\x01\x44\x18\x02 \x03(\x02\x12\t\n\x01K\x18\x03 \x03(\x02\"\\\n\x08Progress\x12\x12\n\npercentage\x18\x01 \x01(\x02\x12\x12\n\nlog_string\x18\x02 \x01(\t\x12(\n\x06status\x18\x03 \x01(\x0e\x32\x18.apollo.dreamview.Status\"\xc0\x01\n\x0fPreprocessTable\x12\x33\n\x0clidar_config\x18\x01 \x03(\x0b\x32\x1d.apollo.dreamview.LidarConfig\x12\x35\n\rcamera_config\x18\x02 \x01(\x0b\x32\x1e.apollo.dreamview.CameraConfig\x12\x13\n\x0bmain_sensor\x18\x03 \x01(\t\x12,\n\x08progress\x18\x04 \x01(\x0b\x32\x1a.apollo.dreamview.Progress*,\n\x06Status\x12\x0b\n\x07SUCCESS\x10\x00\x12\x08\n\x04\x46\x41IL\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02'
)

_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='apollo.dreamview.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=583,
  serialized_end=627,
)
_sym_db.RegisterEnumDescriptor(_STATUS)

Status = enum_type_wrapper.EnumTypeWrapper(_STATUS)
SUCCESS = 0
FAIL = 1
UNKNOWN = 2



_TRANSLATION = _descriptor.Descriptor(
  name='Translation',
  full_name='apollo.dreamview.Translation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.dreamview.Translation.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.dreamview.Translation.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.dreamview.Translation.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=114,
)


_LIDARCONFIG = _descriptor.Descriptor(
  name='LidarConfig',
  full_name='apollo.dreamview.LidarConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_name', full_name='apollo.dreamview.LidarConfig.sensor_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='translation', full_name='apollo.dreamview.LidarConfig.translation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=202,
)


_CAMERACONFIG = _descriptor.Descriptor(
  name='CameraConfig',
  full_name='apollo.dreamview.CameraConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='translation', full_name='apollo.dreamview.CameraConfig.translation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='D', full_name='apollo.dreamview.CameraConfig.D', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='K', full_name='apollo.dreamview.CameraConfig.K', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=292,
)


_PROGRESS = _descriptor.Descriptor(
  name='Progress',
  full_name='apollo.dreamview.Progress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentage', full_name='apollo.dreamview.Progress.percentage', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_string', full_name='apollo.dreamview.Progress.log_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='apollo.dreamview.Progress.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=386,
)


_PREPROCESSTABLE = _descriptor.Descriptor(
  name='PreprocessTable',
  full_name='apollo.dreamview.PreprocessTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lidar_config', full_name='apollo.dreamview.PreprocessTable.lidar_config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_config', full_name='apollo.dreamview.PreprocessTable.camera_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_sensor', full_name='apollo.dreamview.PreprocessTable.main_sensor', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress', full_name='apollo.dreamview.PreprocessTable.progress', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=581,
)

_LIDARCONFIG.fields_by_name['translation'].message_type = _TRANSLATION
_CAMERACONFIG.fields_by_name['translation'].message_type = _TRANSLATION
_PROGRESS.fields_by_name['status'].enum_type = _STATUS
_PREPROCESSTABLE.fields_by_name['lidar_config'].message_type = _LIDARCONFIG
_PREPROCESSTABLE.fields_by_name['camera_config'].message_type = _CAMERACONFIG
_PREPROCESSTABLE.fields_by_name['progress'].message_type = _PROGRESS
DESCRIPTOR.message_types_by_name['Translation'] = _TRANSLATION
DESCRIPTOR.message_types_by_name['LidarConfig'] = _LIDARCONFIG
DESCRIPTOR.message_types_by_name['CameraConfig'] = _CAMERACONFIG
DESCRIPTOR.message_types_by_name['Progress'] = _PROGRESS
DESCRIPTOR.message_types_by_name['PreprocessTable'] = _PREPROCESSTABLE
DESCRIPTOR.enum_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Translation = _reflection.GeneratedProtocolMessageType('Translation', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATION,
  '__module__' : 'modules.dreamview.proto.preprocess_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Translation)
  })
_sym_db.RegisterMessage(Translation)

LidarConfig = _reflection.GeneratedProtocolMessageType('LidarConfig', (_message.Message,), {
  'DESCRIPTOR' : _LIDARCONFIG,
  '__module__' : 'modules.dreamview.proto.preprocess_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.LidarConfig)
  })
_sym_db.RegisterMessage(LidarConfig)

CameraConfig = _reflection.GeneratedProtocolMessageType('CameraConfig', (_message.Message,), {
  'DESCRIPTOR' : _CAMERACONFIG,
  '__module__' : 'modules.dreamview.proto.preprocess_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.CameraConfig)
  })
_sym_db.RegisterMessage(CameraConfig)

Progress = _reflection.GeneratedProtocolMessageType('Progress', (_message.Message,), {
  'DESCRIPTOR' : _PROGRESS,
  '__module__' : 'modules.dreamview.proto.preprocess_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Progress)
  })
_sym_db.RegisterMessage(Progress)

PreprocessTable = _reflection.GeneratedProtocolMessageType('PreprocessTable', (_message.Message,), {
  'DESCRIPTOR' : _PREPROCESSTABLE,
  '__module__' : 'modules.dreamview.proto.preprocess_table_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.PreprocessTable)
  })
_sym_db.RegisterMessage(PreprocessTable)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/network_layers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/network_layers.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-modules/prediction/proto/network_layers.proto\x12\x11\x61pollo.prediction\"2\n\x0fTensorParameter\x12\x10\n\x04\x64\x61ta\x18\x01 \x03(\x02\x42\x02\x10\x01\x12\r\n\x05shape\x18\x02 \x03(\x05\"D\n\x0eInputParameter\x12\x13\n\x0binput_shape\x18\x01 \x03(\x05\x12\r\n\x05\x64type\x18\x02 \x01(\t\x12\x0e\n\x06sparse\x18\x03 \x01(\x08\"\xac\x01\n\x0e\x44\x65nseParameter\x12\r\n\x05units\x18\x01 \x01(\x05\x12\x12\n\nactivation\x18\x02 \x01(\t\x12\x10\n\x08use_bias\x18\x03 \x01(\x08\x12\x33\n\x07weights\x18\x04 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x30\n\x04\x62ias\x18\x05 \x01(\x0b\x32\".apollo.prediction.TensorParameter\"\xa8\x01\n\x0f\x43onv1dParameter\x12\r\n\x05shape\x18\x01 \x03(\x05\x12\x10\n\x08use_bias\x18\x02 \x01(\x08\x12\x32\n\x06kernel\x18\x03 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x30\n\x04\x62ias\x18\x04 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x0e\n\x06stride\x18\x05 \x01(\x05\"9\n\x12MaxPool1dParameter\x12\x13\n\x0bkernel_size\x18\x01 \x01(\x05\x12\x0e\n\x06stride\x18\x02 \x01(\x05\"9\n\x12\x41vgPool1dParameter\x12\x13\n\x0bkernel_size\x18\x01 \x01(\x05\x12\x0e\n\x06stride\x18\x02 \x01(\x05\"\xbc\x02\n\x1b\x42\x61tchNormalizationParameter\x12\x16\n\x07\x65psilon\x18\x01 \x01(\x01:\x05\x31\x65-05\x12\x0c\n\x04\x61xis\x18\x02 \x01(\x05\x12\x0e\n\x06\x63\x65nter\x18\x03 \x01(\x08\x12\r\n\x05scale\x18\x04 \x01(\x08\x12\x10\n\x08momentum\x18\x05 \x01(\x02\x12.\n\x02mu\x18\x06 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x31\n\x05sigma\x18\x07 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x31\n\x05gamma\x18\x08 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x30\n\x04\x62\x65ta\x18\t \x01(\x0b\x32\".apollo.prediction.TensorParameter\"\xe0\x07\n\rLSTMParameter\x12\r\n\x05units\x18\x01 \x01(\x05\x12\x18\n\x10return_sequences\x18\x02 \x01(\x08\x12\x10\n\x08stateful\x18\x03 \x01(\x08\x12\x12\n\nactivation\x18\x04 \x01(\t\x12\x1c\n\x14recurrent_activation\x18\x05 \x01(\t\x12\x10\n\x08use_bias\x18\x06 \x01(\x08\x12\x1e\n\x10unit_forget_bias\x18\x07 \x01(\x08:\x04true\x12\x1b\n\x0cgo_backwards\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\x15\n\x06unroll\x18\t \x01(\x08:\x05\x66\x61lse\x12\x19\n\x0eimplementation\x18\n \x01(\x05:\x01\x30\x12\x39\n\rweights_input\x18\x0f \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12:\n\x0eweights_forget\x18\x10 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x38\n\x0cweights_cell\x18\x11 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12:\n\x0eweights_output\x18\x12 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x36\n\nbias_input\x18\x13 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x37\n\x0b\x62ias_forget\x18\x14 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x35\n\tbias_cell\x18\x15 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x37\n\x0b\x62ias_output\x18\x16 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x43\n\x17recurrent_weights_input\x18\x19 \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x44\n\x18recurrent_weights_forget\x18\x1a \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x42\n\x16recurrent_weights_cell\x18\x1b \x01(\x0b\x32\".apollo.prediction.TensorParameter\x12\x44\n\x18recurrent_weights_output\x18\x1c \x01(\x0b\x32\".apollo.prediction.TensorParameter\")\n\x13\x41\x63tivationParameter\x12\x12\n\nactivation\x18\x01 \x01(\t\"\x12\n\x10\x46lattenParameter\"$\n\x14\x43oncatenateParameter\x12\x0c\n\x04\x61xis\x18\x01 \x01(\x05\"\x9f\x05\n\x0eLayerParameter\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0corder_number\x18\x03 \x01(\x05\x12\x32\n\x05input\x18\x04 \x01(\x0b\x32!.apollo.prediction.InputParameterH\x00\x12<\n\nactivation\x18\x05 \x01(\x0b\x32&.apollo.prediction.ActivationParameterH\x00\x12\x32\n\x05\x64\x65nse\x18\x06 \x01(\x0b\x32!.apollo.prediction.DenseParameterH\x00\x12M\n\x13\x62\x61tch_normalization\x18\x07 \x01(\x0b\x32..apollo.prediction.BatchNormalizationParameterH\x00\x12\x30\n\x04lstm\x18\x08 \x01(\x0b\x32 .apollo.prediction.LSTMParameterH\x00\x12\x36\n\x07\x66latten\x18\t \x01(\x0b\x32#.apollo.prediction.FlattenParameterH\x00\x12>\n\x0b\x63oncatenate\x18\n \x01(\x0b\x32\'.apollo.prediction.ConcatenateParameterH\x00\x12\x34\n\x06\x63onv1d\x18\x0b \x01(\x0b\x32\".apollo.prediction.Conv1dParameterH\x00\x12:\n\tmaxpool1d\x18\x0c \x01(\x0b\x32%.apollo.prediction.MaxPool1dParameterH\x00\x12:\n\tavgpool1d\x18\r \x01(\x0b\x32%.apollo.prediction.AvgPool1dParameterH\x00\x42\x0e\n\x0coneof_layers'
)




_TENSORPARAMETER = _descriptor.Descriptor(
  name='TensorParameter',
  full_name='apollo.prediction.TensorParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='apollo.prediction.TensorParameter.data', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='apollo.prediction.TensorParameter.shape', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=118,
)


_INPUTPARAMETER = _descriptor.Descriptor(
  name='InputParameter',
  full_name='apollo.prediction.InputParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_shape', full_name='apollo.prediction.InputParameter.input_shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dtype', full_name='apollo.prediction.InputParameter.dtype', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sparse', full_name='apollo.prediction.InputParameter.sparse', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=188,
)


_DENSEPARAMETER = _descriptor.Descriptor(
  name='DenseParameter',
  full_name='apollo.prediction.DenseParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='units', full_name='apollo.prediction.DenseParameter.units', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation', full_name='apollo.prediction.DenseParameter.activation', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_bias', full_name='apollo.prediction.DenseParameter.use_bias', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights', full_name='apollo.prediction.DenseParameter.weights', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias', full_name='apollo.prediction.DenseParameter.bias', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=363,
)


_CONV1DPARAMETER = _descriptor.Descriptor(
  name='Conv1dParameter',
  full_name='apollo.prediction.Conv1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='apollo.prediction.Conv1dParameter.shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_bias', full_name='apollo.prediction.Conv1dParameter.use_bias', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kernel', full_name='apollo.prediction.Conv1dParameter.kernel', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias', full_name='apollo.prediction.Conv1dParameter.bias', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='apollo.prediction.Conv1dParameter.stride', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=534,
)


_MAXPOOL1DPARAMETER = _descriptor.Descriptor(
  name='MaxPool1dParameter',
  full_name='apollo.prediction.MaxPool1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kernel_size', full_name='apollo.prediction.MaxPool1dParameter.kernel_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='apollo.prediction.MaxPool1dParameter.stride', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=593,
)


_AVGPOOL1DPARAMETER = _descriptor.Descriptor(
  name='AvgPool1dParameter',
  full_name='apollo.prediction.AvgPool1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kernel_size', full_name='apollo.prediction.AvgPool1dParameter.kernel_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='apollo.prediction.AvgPool1dParameter.stride', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=652,
)


_BATCHNORMALIZATIONPARAMETER = _descriptor.Descriptor(
  name='BatchNormalizationParameter',
  full_name='apollo.prediction.BatchNormalizationParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='epsilon', full_name='apollo.prediction.BatchNormalizationParameter.epsilon', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1e-05),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='apollo.prediction.BatchNormalizationParameter.axis', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center', full_name='apollo.prediction.BatchNormalizationParameter.center', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale', full_name='apollo.prediction.BatchNormalizationParameter.scale', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='momentum', full_name='apollo.prediction.BatchNormalizationParameter.momentum', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mu', full_name='apollo.prediction.BatchNormalizationParameter.mu', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sigma', full_name='apollo.prediction.BatchNormalizationParameter.sigma', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gamma', full_name='apollo.prediction.BatchNormalizationParameter.gamma', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beta', full_name='apollo.prediction.BatchNormalizationParameter.beta', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=971,
)


_LSTMPARAMETER = _descriptor.Descriptor(
  name='LSTMParameter',
  full_name='apollo.prediction.LSTMParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='units', full_name='apollo.prediction.LSTMParameter.units', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_sequences', full_name='apollo.prediction.LSTMParameter.return_sequences', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stateful', full_name='apollo.prediction.LSTMParameter.stateful', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation', full_name='apollo.prediction.LSTMParameter.activation', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurrent_activation', full_name='apollo.prediction.LSTMParameter.recurrent_activation', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_bias', full_name='apollo.prediction.LSTMParameter.use_bias', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_forget_bias', full_name='apollo.prediction.LSTMParameter.unit_forget_bias', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='go_backwards', full_name='apollo.prediction.LSTMParameter.go_backwards', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unroll', full_name='apollo.prediction.LSTMParameter.unroll', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implementation', full_name='apollo.prediction.LSTMParameter.implementation', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights_input', full_name='apollo.prediction.LSTMParameter.weights_input', index=10,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights_forget', full_name='apollo.prediction.LSTMParameter.weights_forget', index=11,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights_cell', full_name='apollo.prediction.LSTMParameter.weights_cell', index=12,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights_output', full_name='apollo.prediction.LSTMParameter.weights_output', index=13,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias_input', full_name='apollo.prediction.LSTMParameter.bias_input', index=14,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias_forget', full_name='apollo.prediction.LSTMParameter.bias_forget', index=15,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias_cell', full_name='apollo.prediction.LSTMParameter.bias_cell', index=16,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias_output', full_name='apollo.prediction.LSTMParameter.bias_output', index=17,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurrent_weights_input', full_name='apollo.prediction.LSTMParameter.recurrent_weights_input', index=18,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurrent_weights_forget', full_name='apollo.prediction.LSTMParameter.recurrent_weights_forget', index=19,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurrent_weights_cell', full_name='apollo.prediction.LSTMParameter.recurrent_weights_cell', index=20,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurrent_weights_output', full_name='apollo.prediction.LSTMParameter.recurrent_weights_output', index=21,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=974,
  serialized_end=1966,
)


_ACTIVATIONPARAMETER = _descriptor.Descriptor(
  name='ActivationParameter',
  full_name='apollo.prediction.ActivationParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='activation', full_name='apollo.prediction.ActivationParameter.activation', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1968,
  serialized_end=2009,
)


_FLATTENPARAMETER = _descriptor.Descriptor(
  name='FlattenParameter',
  full_name='apollo.prediction.FlattenParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2011,
  serialized_end=2029,
)


_CONCATENATEPARAMETER = _descriptor.Descriptor(
  name='ConcatenateParameter',
  full_name='apollo.prediction.ConcatenateParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='axis', full_name='apollo.prediction.ConcatenateParameter.axis', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2031,
  serialized_end=2067,
)


_LAYERPARAMETER = _descriptor.Descriptor(
  name='LayerParameter',
  full_name='apollo.prediction.LayerParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.prediction.LayerParameter.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.prediction.LayerParameter.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_number', full_name='apollo.prediction.LayerParameter.order_number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input', full_name='apollo.prediction.LayerParameter.input', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation', full_name='apollo.prediction.LayerParameter.activation', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dense', full_name='apollo.prediction.LayerParameter.dense', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_normalization', full_name='apollo.prediction.LayerParameter.batch_normalization', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lstm', full_name='apollo.prediction.LayerParameter.lstm', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flatten', full_name='apollo.prediction.LayerParameter.flatten', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='concatenate', full_name='apollo.prediction.LayerParameter.concatenate', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conv1d', full_name='apollo.prediction.LayerParameter.conv1d', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxpool1d', full_name='apollo.prediction.LayerParameter.maxpool1d', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avgpool1d', full_name='apollo.prediction.LayerParameter.avgpool1d', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_layers', full_name='apollo.prediction.LayerParameter.oneof_layers',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2070,
  serialized_end=2741,
)

_DENSEPARAMETER.fields_by_name['weights'].message_type = _TENSORPARAMETER
_DENSEPARAMETER.fields_by_name['bias'].message_type = _TENSORPARAMETER
_CONV1DPARAMETER.fields_by_name['kernel'].message_type = _TENSORPARAMETER
_CONV1DPARAMETER.fields_by_name['bias'].message_type = _TENSORPARAMETER
_BATCHNORMALIZATIONPARAMETER.fields_by_name['mu'].message_type = _TENSORPARAMETER
_BATCHNORMALIZATIONPARAMETER.fields_by_name['sigma'].message_type = _TENSORPARAMETER
_BATCHNORMALIZATIONPARAMETER.fields_by_name['gamma'].message_type = _TENSORPARAMETER
_BATCHNORMALIZATIONPARAMETER.fields_by_name['beta'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['weights_input'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['weights_forget'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['weights_cell'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['weights_output'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['bias_input'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['bias_forget'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['bias_cell'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['bias_output'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['recurrent_weights_input'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['recurrent_weights_forget'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['recurrent_weights_cell'].message_type = _TENSORPARAMETER
_LSTMPARAMETER.fields_by_name['recurrent_weights_output'].message_type = _TENSORPARAMETER
_LAYERPARAMETER.fields_by_name['input'].message_type = _INPUTPARAMETER
_LAYERPARAMETER.fields_by_name['activation'].message_type = _ACTIVATIONPARAMETER
_LAYERPARAMETER.fields_by_name['dense'].message_type = _DENSEPARAMETER
_LAYERPARAMETER.fields_by_name['batch_normalization'].message_type = _BATCHNORMALIZATIONPARAMETER
_LAYERPARAMETER.fields_by_name['lstm'].message_type = _LSTMPARAMETER
_LAYERPARAMETER.fields_by_name['flatten'].message_type = _FLATTENPARAMETER
_LAYERPARAMETER.fields_by_name['concatenate'].message_type = _CONCATENATEPARAMETER
_LAYERPARAMETER.fields_by_name['conv1d'].message_type = _CONV1DPARAMETER
_LAYERPARAMETER.fields_by_name['maxpool1d'].message_type = _MAXPOOL1DPARAMETER
_LAYERPARAMETER.fields_by_name['avgpool1d'].message_type = _AVGPOOL1DPARAMETER
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['input'])
_LAYERPARAMETER.fields_by_name['input'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['activation'])
_LAYERPARAMETER.fields_by_name['activation'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['dense'])
_LAYERPARAMETER.fields_by_name['dense'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['batch_normalization'])
_LAYERPARAMETER.fields_by_name['batch_normalization'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['lstm'])
_LAYERPARAMETER.fields_by_name['lstm'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['flatten'])
_LAYERPARAMETER.fields_by_name['flatten'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['concatenate'])
_LAYERPARAMETER.fields_by_name['concatenate'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['conv1d'])
_LAYERPARAMETER.fields_by_name['conv1d'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['maxpool1d'])
_LAYERPARAMETER.fields_by_name['maxpool1d'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
_LAYERPARAMETER.oneofs_by_name['oneof_layers'].fields.append(
  _LAYERPARAMETER.fields_by_name['avgpool1d'])
_LAYERPARAMETER.fields_by_name['avgpool1d'].containing_oneof = _LAYERPARAMETER.oneofs_by_name['oneof_layers']
DESCRIPTOR.message_types_by_name['TensorParameter'] = _TENSORPARAMETER
DESCRIPTOR.message_types_by_name['InputParameter'] = _INPUTPARAMETER
DESCRIPTOR.message_types_by_name['DenseParameter'] = _DENSEPARAMETER
DESCRIPTOR.message_types_by_name['Conv1dParameter'] = _CONV1DPARAMETER
DESCRIPTOR.message_types_by_name['MaxPool1dParameter'] = _MAXPOOL1DPARAMETER
DESCRIPTOR.message_types_by_name['AvgPool1dParameter'] = _AVGPOOL1DPARAMETER
DESCRIPTOR.message_types_by_name['BatchNormalizationParameter'] = _BATCHNORMALIZATIONPARAMETER
DESCRIPTOR.message_types_by_name['LSTMParameter'] = _LSTMPARAMETER
DESCRIPTOR.message_types_by_name['ActivationParameter'] = _ACTIVATIONPARAMETER
DESCRIPTOR.message_types_by_name['FlattenParameter'] = _FLATTENPARAMETER
DESCRIPTOR.message_types_by_name['ConcatenateParameter'] = _CONCATENATEPARAMETER
DESCRIPTOR.message_types_by_name['LayerParameter'] = _LAYERPARAMETER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TensorParameter = _reflection.GeneratedProtocolMessageType('TensorParameter', (_message.Message,), {
  'DESCRIPTOR' : _TENSORPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.TensorParameter)
  })
_sym_db.RegisterMessage(TensorParameter)

InputParameter = _reflection.GeneratedProtocolMessageType('InputParameter', (_message.Message,), {
  'DESCRIPTOR' : _INPUTPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.InputParameter)
  })
_sym_db.RegisterMessage(InputParameter)

DenseParameter = _reflection.GeneratedProtocolMessageType('DenseParameter', (_message.Message,), {
  'DESCRIPTOR' : _DENSEPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.DenseParameter)
  })
_sym_db.RegisterMessage(DenseParameter)

Conv1dParameter = _reflection.GeneratedProtocolMessageType('Conv1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _CONV1DPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Conv1dParameter)
  })
_sym_db.RegisterMessage(Conv1dParameter)

MaxPool1dParameter = _reflection.GeneratedProtocolMessageType('MaxPool1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _MAXPOOL1DPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.MaxPool1dParameter)
  })
_sym_db.RegisterMessage(MaxPool1dParameter)

AvgPool1dParameter = _reflection.GeneratedProtocolMessageType('AvgPool1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _AVGPOOL1DPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.AvgPool1dParameter)
  })
_sym_db.RegisterMessage(AvgPool1dParameter)

BatchNormalizationParameter = _reflection.GeneratedProtocolMessageType('BatchNormalizationParameter', (_message.Message,), {
  'DESCRIPTOR' : _BATCHNORMALIZATIONPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.BatchNormalizationParameter)
  })
_sym_db.RegisterMessage(BatchNormalizationParameter)

LSTMParameter = _reflection.GeneratedProtocolMessageType('LSTMParameter', (_message.Message,), {
  'DESCRIPTOR' : _LSTMPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.LSTMParameter)
  })
_sym_db.RegisterMessage(LSTMParameter)

ActivationParameter = _reflection.GeneratedProtocolMessageType('ActivationParameter', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATIONPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ActivationParameter)
  })
_sym_db.RegisterMessage(ActivationParameter)

FlattenParameter = _reflection.GeneratedProtocolMessageType('FlattenParameter', (_message.Message,), {
  'DESCRIPTOR' : _FLATTENPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.FlattenParameter)
  })
_sym_db.RegisterMessage(FlattenParameter)

ConcatenateParameter = _reflection.GeneratedProtocolMessageType('ConcatenateParameter', (_message.Message,), {
  'DESCRIPTOR' : _CONCATENATEPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ConcatenateParameter)
  })
_sym_db.RegisterMessage(ConcatenateParameter)

LayerParameter = _reflection.GeneratedProtocolMessageType('LayerParameter', (_message.Message,), {
  'DESCRIPTOR' : _LAYERPARAMETER,
  '__module__' : 'modules.prediction.proto.network_layers_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.LayerParameter)
  })
_sym_db.RegisterMessage(LayerParameter)


_TENSORPARAMETER.fields_by_name['data']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/localization/proto/localization.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.localization.proto import pose_pb2 as modules_dot_localization_dot_proto_dot_pose__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.localization.proto import localization_status_pb2 as modules_dot_localization_dot_proto_dot_localization__status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/localization/proto/localization.proto',
  package='apollo.localization',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-modules/localization/proto/localization.proto\x12\x13\x61pollo.localization\x1a!modules/common/proto/header.proto\x1a%modules/localization/proto/pose.proto\x1a#modules/common/proto/geometry.proto\x1a$modules/common/proto/pnc_point.proto\x1a\x34modules/localization/proto/localization_status.proto\"\xa4\x02\n\x0bUncertainty\x12\x30\n\x10position_std_dev\x18\x01 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x33\n\x13orientation_std_dev\x18\x02 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x37\n\x17linear_velocity_std_dev\x18\x03 \x01(\x0b\x32\x16.apollo.common.Point3D\x12;\n\x1blinear_acceleration_std_dev\x18\x04 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x38\n\x18\x61ngular_velocity_std_dev\x18\x05 \x01(\x0b\x32\x16.apollo.common.Point3D\"\xe5\x02\n\x14LocalizationEstimate\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\'\n\x04pose\x18\x02 \x01(\x0b\x32\x19.apollo.localization.Pose\x12\x35\n\x0buncertainty\x18\x03 \x01(\x0b\x32 .apollo.localization.Uncertainty\x12\x18\n\x10measurement_time\x18\x04 \x01(\x01\x12\x38\n\x10trajectory_point\x18\x05 \x03(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12\x32\n\nmsf_status\x18\x06 \x01(\x0b\x32\x1e.apollo.localization.MsfStatus\x12>\n\rsensor_status\x18\x07 \x01(\x0b\x32\'.apollo.localization.MsfSensorMsgStatus\"\x9f\x02\n\x12LocalizationStatus\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x38\n\rfusion_status\x18\x02 \x01(\x0e\x32!.apollo.localization.MeasureState\x12:\n\x0bgnss_status\x18\x03 \x01(\x0e\x32!.apollo.localization.MeasureStateB\x02\x18\x01\x12;\n\x0clidar_status\x18\x04 \x01(\x0e\x32!.apollo.localization.MeasureStateB\x02\x18\x01\x12\x18\n\x10measurement_time\x18\x05 \x01(\x01\x12\x15\n\rstate_message\x18\x06 \x01(\t*T\n\x0cMeasureState\x12\x06\n\x02OK\x10\x00\x12\x0c\n\x08WARNNING\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x12\n\x0e\x43RITICAL_ERROR\x10\x03\x12\x0f\n\x0b\x46\x41TAL_ERROR\x10\x04'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_localization_dot_proto_dot_pose__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_localization_dot_proto_dot_localization__status__pb2.DESCRIPTOR,])

_MEASURESTATE = _descriptor.EnumDescriptor(
  name='MeasureState',
  full_name='apollo.localization.MeasureState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL_ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FATAL_ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1218,
  serialized_end=1302,
)
_sym_db.RegisterEnumDescriptor(_MEASURESTATE)

MeasureState = enum_type_wrapper.EnumTypeWrapper(_MEASURESTATE)
OK = 0
WARNNING = 1
ERROR = 2
CRITICAL_ERROR = 3
FATAL_ERROR = 4



_UNCERTAINTY = _descriptor.Descriptor(
  name='Uncertainty',
  full_name='apollo.localization.Uncertainty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position_std_dev', full_name='apollo.localization.Uncertainty.position_std_dev', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation_std_dev', full_name='apollo.localization.Uncertainty.orientation_std_dev', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity_std_dev', full_name='apollo.localization.Uncertainty.linear_velocity_std_dev', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_acceleration_std_dev', full_name='apollo.localization.Uncertainty.linear_acceleration_std_dev', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity_std_dev', full_name='apollo.localization.Uncertainty.angular_velocity_std_dev', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=274,
  serialized_end=566,
)


_LOCALIZATIONESTIMATE = _descriptor.Descriptor(
  name='LocalizationEstimate',
  full_name='apollo.localization.LocalizationEstimate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.localization.LocalizationEstimate.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='apollo.localization.LocalizationEstimate.pose', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uncertainty', full_name='apollo.localization.LocalizationEstimate.uncertainty', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_time', full_name='apollo.localization.LocalizationEstimate.measurement_time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_point', full_name='apollo.localization.LocalizationEstimate.trajectory_point', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msf_status', full_name='apollo.localization.LocalizationEstimate.msf_status', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensor_status', full_name='apollo.localization.LocalizationEstimate.sensor_status', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=926,
)


_LOCALIZATIONSTATUS = _descriptor.Descriptor(
  name='LocalizationStatus',
  full_name='apollo.localization.LocalizationStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.localization.LocalizationStatus.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fusion_status', full_name='apollo.localization.LocalizationStatus.fusion_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_status', full_name='apollo.localization.LocalizationStatus.gnss_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lidar_status', full_name='apollo.localization.LocalizationStatus.lidar_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_time', full_name='apollo.localization.LocalizationStatus.measurement_time', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_message', full_name='apollo.localization.LocalizationStatus.state_message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=929,
  serialized_end=1216,
)

_UNCERTAINTY.fields_by_name['position_std_dev'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_UNCERTAINTY.fields_by_name['orientation_std_dev'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_UNCERTAINTY.fields_by_name['linear_velocity_std_dev'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_UNCERTAINTY.fields_by_name['linear_acceleration_std_dev'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_UNCERTAINTY.fields_by_name['angular_velocity_std_dev'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_LOCALIZATIONESTIMATE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_LOCALIZATIONESTIMATE.fields_by_name['pose'].message_type = modules_dot_localization_dot_proto_dot_pose__pb2._POSE
_LOCALIZATIONESTIMATE.fields_by_name['uncertainty'].message_type = _UNCERTAINTY
_LOCALIZATIONESTIMATE.fields_by_name['trajectory_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_LOCALIZATIONESTIMATE.fields_by_name['msf_status'].message_type = modules_dot_localization_dot_proto_dot_localization__status__pb2._MSFSTATUS
_LOCALIZATIONESTIMATE.fields_by_name['sensor_status'].message_type = modules_dot_localization_dot_proto_dot_localization__status__pb2._MSFSENSORMSGSTATUS
_LOCALIZATIONSTATUS.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_LOCALIZATIONSTATUS.fields_by_name['fusion_status'].enum_type = _MEASURESTATE
_LOCALIZATIONSTATUS.fields_by_name['gnss_status'].enum_type = _MEASURESTATE
_LOCALIZATIONSTATUS.fields_by_name['lidar_status'].enum_type = _MEASURESTATE
DESCRIPTOR.message_types_by_name['Uncertainty'] = _UNCERTAINTY
DESCRIPTOR.message_types_by_name['LocalizationEstimate'] = _LOCALIZATIONESTIMATE
DESCRIPTOR.message_types_by_name['LocalizationStatus'] = _LOCALIZATIONSTATUS
DESCRIPTOR.enum_types_by_name['MeasureState'] = _MEASURESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Uncertainty = _reflection.GeneratedProtocolMessageType('Uncertainty', (_message.Message,), {
  'DESCRIPTOR' : _UNCERTAINTY,
  '__module__' : 'modules.localization.proto.localization_pb2'
  # @@protoc_insertion_point(class_scope:apollo.localization.Uncertainty)
  })
_sym_db.RegisterMessage(Uncertainty)

LocalizationEstimate = _reflection.GeneratedProtocolMessageType('LocalizationEstimate', (_message.Message,), {
  'DESCRIPTOR' : _LOCALIZATIONESTIMATE,
  '__module__' : 'modules.localization.proto.localization_pb2'
  # @@protoc_insertion_point(class_scope:apollo.localization.LocalizationEstimate)
  })
_sym_db.RegisterMessage(LocalizationEstimate)

LocalizationStatus = _reflection.GeneratedProtocolMessageType('LocalizationStatus', (_message.Message,), {
  'DESCRIPTOR' : _LOCALIZATIONSTATUS,
  '__module__' : 'modules.localization.proto.localization_pb2'
  # @@protoc_insertion_point(class_scope:apollo.localization.LocalizationStatus)
  })
_sym_db.RegisterMessage(LocalizationStatus)


_LOCALIZATIONSTATUS.fields_by_name['gnss_status']._options = None
_LOCALIZATIONSTATUS.fields_by_name['lidar_status']._options = None
# @@protoc_insertion_point(module_scope)
